# PCBA
PCB Assembly. Soldering. SMT. Thru hole. Stencils. Paste. Equipment. Tools. HOWTOs.

This document is available here:
https://code.forksand.com/forksand/pcba/src/branch/master/README.md

License: CC By SA 4.0 International and/or GPLv3+ at your discretion.
Other code licensed under their own respective licenses.

Copyright © 2019, Fork Sand, Inc.

# Prototype PCBA Manufacturing
This documents free software and open source hardware manufacturing
of PCBAs (Printed Circuit Board Assemblies).

Focus is particularly on tools that can be used with hackerspace-
level technology.

# Software
Various Free Software (as defined by FSF) applications available
for the creation of PCBAs.

## Debian
The below packages are in Debian Buster. Note, even though it is in
Debian, you may want to build some of these packages from scratch
since the version in Debian is old. Debian `backports` maintains
an up to date KiCAD.

The following Debian packages are in use in the current production toolchain:

* `freecad` --- Visualization of PCBAs and more. 3D CAD application.

* `inkscape` --- vector-based drawing program.

* `kicad` --- Electronic schematic and PCB design software.

The following Debian packages are NOT in use:

* `electronics-pcb` --- Debian packages for PCB development (meta package).

* `fritzing` --- Easy-to-use electronic design software.

* `geda` --- GPL EDA -- Electronics design software.

* `gerbv` --- Gerber file viewer.

* `lepton-eda` --- Lepton Electronic Design Automation.

* `pcb` --- printed circuit board (pcb) design program.

* `pcb2gcode` --- command-line tool for engraving PCBs using CNCs.

* `pcb-rnd` - Modular Printed Circuit Board layout tool.

* `visolate` - tool for engraving PCBs using CNCs.

## Other
Other PCBA software available under Free Software licenses.

Used:

* J-Tech Photonics LASER Inkscape Plugin.

* `raster2gcode` --- Inkscape Plugin.

Not Used:

* `InteractiveHtmlBom` --- Interactive HTML BOM generation plugin for KiCad
https://github.com/openscopeproject/InteractiveHtmlBom

* `OpenPNP` --- Pick and Place software.

## Electronic Design Automation (EDA)
To design PCBs, KiCAD is used.
Export Gerber files for manufacturing.

# PCB Manufacturing.
You can make your own PCB or have them made by numerous suppliers.
Recommended suppliers (amongst many):

* OSHPark --- Strong FLO supporters, high quality, quick turn, USA.

* DirtyPCBs --- Lowest possible cost out of Shenzhen, China.

* ProtoExpress -- Quick turn, high quality, high cost, USA.

* Many others that also support KiCAD!

## Board Types and Features
FR1, FR4, etc.

## Copper Layer
Cu later.

## Soldermask
Green...

## Silkscreen
White...

## Standards & QC
Standards:

* RoHS (no lead).

* cf. NASA Standards.

# PCB Assembly
You can have a board assembled by a house such as ProtoExpress,
or you can assemble it yourself. There is an endless variety of
DIY approaches to this. This you have the PCB finished. You need to:

* Source components.

* Place components.

* Solder Components.

## Placement
The many ways to place a part...

* Fingers.

* Tweezers.

* Vacuum.

* Pick and Place.

What method is used depends on the type and size of the part
and what equipment is available. We'll be working with SMT,
BGA, and through hole parts.

## Solder Paste
To solder SMT parts to PCB.

In use:

* CHIPQUIK SMD291SNL50T3, 50g jar.

* Zeph ZeroLead, 96.5Sn / 3Ag /.5Cu, 10cc syringe.

## Solder Wire
In use:

* Kester K1000D, no clean, no lead, 0.8mm.

* Kester Sn96.5Ag3.0Cu0.5, no clean, no lead, 0.8mm.

## Flux
In use:

* Zephlux No Clean Flux, 14 gr. jar.

## Flux Remover
But you just put flux on...

In use:

* Zeph Flux Remover.

## Low Melt Alloy
To desolder, perchance.

* Zeph ZERO No Lead Low Melt.

## Solder Wick
Solder wick, aka desoldering wire.

In use: variety sizes.

## Heat
You need to melt that solder...

* Solder Iron.

* Skillet.

* Oven.

* Hot air pencil.

* Hot air bath.

# PCBA Processes
Working with PCBs and components:

## Solder through hole components with soldering iron
HOWTO solder through hole components to a PCB with soldering.

## Solder SMT components with soldering iron
HOWTO Solder SMT components with soldering iron.

## Solder SMT components with hot air
HOWTO Solder SMT components with hot air.

## Solder SMT components with oven
HOWTO Solder SMT components with oven.

## Solder SMT components with skillet
HOWTO Solder SMT components with skillet.

## Solder BGA components
HOWTO Solder BGA components.

## Rework through hole components
HOWTO Rework through hole components.

## Rework SMT components
HOWTO Rework SMT components.

## Rework BGA components
HOWTO Rework BGA components.

## Create solder paste stencil
HOWTO Create solder paste stencil.

Current Practice:

* [HOWTO create a solder paste stencil with Inkscape]
(HOWTO/laser-solder-paste-stencil-inkscape.md)

## Apply solder paste with solder paste mask
HOWTO Apply solder paste with solder paste mask.

## Apply solder paste with syringe
HOWTO Apply solder paste with syringe.

## Apply solder paste with electronic syringe
HOWTO Apply solder paste with electronic syringe.


# PCBA Testing
Pins.

# Equipment
The equipment considered is what is generally available to
hackerspaces. This leaves out industrial gear like large
wave solder machines.

## LASER
LASERS can serve a few purposes in manufacturing PCBAs.
Inexpensive LASER cutters are available at many hackerspaces.
Inexpensive LASERs can be retrofit to RepRap 3D printers.

* Cut solder paste stencils.

* Etch paint, which is then chemically etched.

* Board marking, such as serialization.

## CNC
Large CNCs are overkill for PCBA assembly.
Very small CNCs can be used.
CNCs are available at many hackerspaces.
CNCs can be used to:

* Engrave PCB.

* Drill PCB holes.


## 3D Printer
RepRap 3D printers are available at many hackerspaces.
3D printers can be used to:

* Make CNC fixtures.

* Make board holding fixtures.

* Make other tools, etc.

## Solder Station
Solder station tools:

* Soldering iron.

* Hot air pencil.

* Hot air bath.

* Fume extrator.

* PCB holder.

* Lights.

* Magnification.

* Solder paste dispenser.

* Vacuum pencil.

* Oven.

* Heat plate.

* Solder pot.

## Pick and Place
A variety of free software compatible and open source hardware
pick and place machines are available.

* OpenPNP designs.

* LitePlacer. Note, works with Free Software OpenPNP, but is
non-commercial design licensed hardware. Manufacturer supplies
proprietary application.

# Production Boards
Boards manufactured or slated to be manufactured.

* Trellisboard --- Ultimate ECP5 board.
https://code.forksand.com/forksand/fs-TrellisBoard

* ULX3X --- ECP5 board.
https://code.forksand.com/forksand/fs-ulx3s
